Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GRPCServiceServer ¶
type GRPCServiceServer interface {
pbns.NodeStatusServer
pbfs.FailureStatusServer
// Serve will serve the services.
Serve(addr string) error
}
GRPCServiceServer is an interface that wraps all the GRPC service need to implement.
type MasterGRPCServiceServer ¶
type MasterGRPCServiceServer struct {
*grpcservice.NodeStatus
*grpcservice.FailureStatus
// contains filtered or unexported fields
}
MasterGRPCServiceServer is an implementation of the service server using using master implementation as logic, it wraps all the services used as.
func NewMasterGRPCServiceServer ¶
func NewMasterGRPCServiceServer(fss service.FailureStatusService, nss service.NodeStatusService, listener net.Listener, clock clock.Clock, logger log.Logger) *MasterGRPCServiceServer
NewMasterGRPCServiceServer returns a new grpc service server with a master as a base.
func (*MasterGRPCServiceServer) Serve ¶
func (m *MasterGRPCServiceServer) Serve() error
Serve implements the GRPCServiceServiceServer interface.
Click to show internal directories.
Click to hide internal directories.